==> haskell-ghc-check-0.5.0.6-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-check
version:              0.5.0.6
visibility:           public
id:                   ghc-check-0.5.0.6-EI3j9PfrJAt1yGacY4XuWc
key:                  ghc-check-0.5.0.6-EI3j9PfrJAt1yGacY4XuWc
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  a6a045a9bed0a993686df93ce91e9c4d
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.0.1/site-local/ghc-check-0.5.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/ghc-check-0.5.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/ghc-check-0.5.0.6
hs-libraries:         HSghc-check-0.5.0.6-EI3j9PfrJAt1yGacY4XuWc
depends:
    base-4.15.0.0 containers-0.6.4.1 directory-1.3.6.1 filepath-1.4.2.1
    ghc-9.0.1 ghc-paths-0.1.0.12-D0EghxpsajHHuX2KoHY7KF
    process-1.6.11.0 safe-exceptions-0.1.7.2-Glme6bYKM7cHHvRWo0df7k
    template-haskell-2.17.0.0 th-compat-0.1.3-LSdVqXT92twKdUNsR1uwyd
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-check-0.5.0.6-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-check
version:              0.5.0.6
visibility:           public
id:                   ghc-check-0.5.0.6-8J0QEFFNLSuGEnwVS70JGH
key:                  ghc-check-0.5.0.6-8J0QEFFNLSuGEnwVS70JGH
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  36567d95016996257e49c0a8fc489d18
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.0.1/site-local/ghc-check-0.5.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/ghc-check-0.5.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/ghc-check-0.5.0.6
hs-libraries:         HSghc-check-0.5.0.6-8J0QEFFNLSuGEnwVS70JGH
depends:
    base-4.15.0.0 containers-0.6.4.1 directory-1.3.6.1 filepath-1.4.2.1
    ghc-9.0.1 ghc-paths-0.1.0.12-D0EghxpsajHHuX2KoHY7KF
    process-1.6.11.0 safe-exceptions-0.1.7.2-L3AELrIzgQrFv86s1DNxnl
    template-haskell-2.17.0.0 th-compat-0.1.3-C8tKgkZHramC73P5mODKxv
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
